pub struct InFlightRequest<Req, Res> { /* private fields */ }Expand description
A request produced by Channel::requests.
If dropped without calling execute, a cancellation message will
be sent to the Channel to clean up associated request state.
Implementations
Sourceimpl<Req, Res> InFlightRequest<Req, Res>
impl<Req, Res> InFlightRequest<Req, Res>
Sourcepub async fn execute<S>(self, serve: S)where
S: Serve<Req, Resp = Res>,
pub async fn execute<S>(self, serve: S)where
S: Serve<Req, Resp = Res>,
Returns a future that executes the request using the given service function. The service function’s output is automatically sent back to the Channel that yielded this request. The request will be executed in the scope of this request’s context.
The returned future will stop executing when the first of the following conditions is met:
- The channel that yielded this request receives a cancellation message for this request.
- The request deadline is reached.
- The service function completes.
If the returned Future is dropped before completion, a cancellation message will be sent to the Channel to clean up associated request state.