pub struct TrackedRequest<Req> {
pub request: Request<Req>,
pub abort_registration: AbortRegistration,
pub span: Span,
pub response_guard: ResponseGuard,
}Expand description
A request tracked by a Channel.
Fields
request: Request<Req>The request sent by the client.
abort_registration: AbortRegistrationA registration to abort a future when the Channel that produced this request stops
tracking it.
span: SpanA span representing the server processing of this request.
response_guard: ResponseGuardAn inert response guard. Becomes active in an InFlightRequest.